defmodule RecycledCloud.Application do
  # See https://hexdocs.pm/elixir/Application.html
  # for more information on OTP Applications
  @moduledoc false

  use Application

  def start(_type, _args) do
    children = [
      # Start the Ecto repository
      RecycledCloud.Repo,
      # Start the Telemetry supervisor
      RecycledCloudWeb.Telemetry,
      # Start the PubSub system
      {Phoenix.PubSub, name: RecycledCloud.PubSub},
      # Start the Endpoint (http/https)
      RecycledCloudWeb.Endpoint,
      # Starts LDAP connection pool
      RecycledCloud.LDAP
      # Start a worker by calling: RecycledCloud.Worker.start_link(arg)
      # {RecycledCloud.Worker, arg}
    ]

    # See https://hexdocs.pm/elixir/Supervisor.html
    # for other strategies and supported options
    opts = [strategy: :one_for_one, name: RecycledCloud.Supervisor]
    Supervisor.start_link(children, opts)
  end

  # Tell Phoenix to update the endpoint configuration
  # whenever the application is updated.
  def config_change(changed, _new, removed) do
    RecycledCloudWeb.Endpoint.config_change(changed, removed)
    :ok
  end
end
